"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.paginateListChannels = void 0;
const ListChannelsCommand_1 = require("../commands/ListChannelsCommand");
const MediaPackage_1 = require("../MediaPackage");
const MediaPackageClient_1 = require("../MediaPackageClient");
const makePagedClientRequest = async (client, input, ...args) => {
    return await client.send(new ListChannelsCommand_1.ListChannelsCommand(input), ...args);
};
const makePagedRequest = async (client, input, ...args) => {
    return await client.listChannels(input, ...args);
};
async function* paginateListChannels(config, input, ...additionalArguments) {
    let token = config.startingToken || undefined;
    let hasNext = true;
    let page;
    while (hasNext) {
        input.NextToken = token;
        input["MaxResults"] = config.pageSize;
        if (config.client instanceof MediaPackage_1.MediaPackage) {
            page = await makePagedRequest(config.client, input, ...additionalArguments);
        }
        else if (config.client instanceof MediaPackageClient_1.MediaPackageClient) {
            page = await makePagedClientRequest(config.client, input, ...additionalArguments);
        }
        else {
            throw new Error("Invalid client, expected MediaPackage | MediaPackageClient");
        }
        yield page;
        token = page.NextToken;
        hasNext = !!token;
    }
    return undefined;
}
exports.paginateListChannels = paginateListChannels;
