import { EndpointsInputConfig, EndpointsResolvedConfig, RegionInputConfig, RegionResolvedConfig } from "@aws-sdk/config-resolver";
import { HostHeaderInputConfig, HostHeaderResolvedConfig } from "@aws-sdk/middleware-host-header";
import { RetryInputConfig, RetryResolvedConfig } from "@aws-sdk/middleware-retry";
import { AwsAuthInputConfig, AwsAuthResolvedConfig } from "@aws-sdk/middleware-signing";
import { UserAgentInputConfig, UserAgentResolvedConfig } from "@aws-sdk/middleware-user-agent";
import { HttpHandler as __HttpHandler } from "@aws-sdk/protocol-http";
import { Client as __Client, DefaultsMode, SmithyConfiguration as __SmithyConfiguration, SmithyResolvedConfiguration as __SmithyResolvedConfiguration } from "@aws-sdk/smithy-client";
import { BodyLengthCalculator as __BodyLengthCalculator, Credentials as __Credentials, Decoder as __Decoder, Encoder as __Encoder, HashConstructor as __HashConstructor, HttpHandlerOptions as __HttpHandlerOptions, Logger as __Logger, Provider as __Provider, Provider, RegionInfoProvider, StreamCollector as __StreamCollector, UrlParser as __UrlParser, UserAgent as __UserAgent } from "@aws-sdk/types";
import { ConfigureLogsCommandInput, ConfigureLogsCommandOutput } from "./commands/ConfigureLogsCommand";
import { CreateChannelCommandInput, CreateChannelCommandOutput } from "./commands/CreateChannelCommand";
import { CreateHarvestJobCommandInput, CreateHarvestJobCommandOutput } from "./commands/CreateHarvestJobCommand";
import { CreateOriginEndpointCommandInput, CreateOriginEndpointCommandOutput } from "./commands/CreateOriginEndpointCommand";
import { DeleteChannelCommandInput, DeleteChannelCommandOutput } from "./commands/DeleteChannelCommand";
import { DeleteOriginEndpointCommandInput, DeleteOriginEndpointCommandOutput } from "./commands/DeleteOriginEndpointCommand";
import { DescribeChannelCommandInput, DescribeChannelCommandOutput } from "./commands/DescribeChannelCommand";
import { DescribeHarvestJobCommandInput, DescribeHarvestJobCommandOutput } from "./commands/DescribeHarvestJobCommand";
import { DescribeOriginEndpointCommandInput, DescribeOriginEndpointCommandOutput } from "./commands/DescribeOriginEndpointCommand";
import { ListChannelsCommandInput, ListChannelsCommandOutput } from "./commands/ListChannelsCommand";
import { ListHarvestJobsCommandInput, ListHarvestJobsCommandOutput } from "./commands/ListHarvestJobsCommand";
import { ListOriginEndpointsCommandInput, ListOriginEndpointsCommandOutput } from "./commands/ListOriginEndpointsCommand";
import { ListTagsForResourceCommandInput, ListTagsForResourceCommandOutput } from "./commands/ListTagsForResourceCommand";
import { RotateChannelCredentialsCommandInput, RotateChannelCredentialsCommandOutput } from "./commands/RotateChannelCredentialsCommand";
import { RotateIngestEndpointCredentialsCommandInput, RotateIngestEndpointCredentialsCommandOutput } from "./commands/RotateIngestEndpointCredentialsCommand";
import { TagResourceCommandInput, TagResourceCommandOutput } from "./commands/TagResourceCommand";
import { UntagResourceCommandInput, UntagResourceCommandOutput } from "./commands/UntagResourceCommand";
import { UpdateChannelCommandInput, UpdateChannelCommandOutput } from "./commands/UpdateChannelCommand";
import { UpdateOriginEndpointCommandInput, UpdateOriginEndpointCommandOutput } from "./commands/UpdateOriginEndpointCommand";
export declare type ServiceInputTypes = ConfigureLogsCommandInput | CreateChannelCommandInput | CreateHarvestJobCommandInput | CreateOriginEndpointCommandInput | DeleteChannelCommandInput | DeleteOriginEndpointCommandInput | DescribeChannelCommandInput | DescribeHarvestJobCommandInput | DescribeOriginEndpointCommandInput | ListChannelsCommandInput | ListHarvestJobsCommandInput | ListOriginEndpointsCommandInput | ListTagsForResourceCommandInput | RotateChannelCredentialsCommandInput | RotateIngestEndpointCredentialsCommandInput | TagResourceCommandInput | UntagResourceCommandInput | UpdateChannelCommandInput | UpdateOriginEndpointCommandInput;
export declare type ServiceOutputTypes = ConfigureLogsCommandOutput | CreateChannelCommandOutput | CreateHarvestJobCommandOutput | CreateOriginEndpointCommandOutput | DeleteChannelCommandOutput | DeleteOriginEndpointCommandOutput | DescribeChannelCommandOutput | DescribeHarvestJobCommandOutput | DescribeOriginEndpointCommandOutput | ListChannelsCommandOutput | ListHarvestJobsCommandOutput | ListOriginEndpointsCommandOutput | ListTagsForResourceCommandOutput | RotateChannelCredentialsCommandOutput | RotateIngestEndpointCredentialsCommandOutput | TagResourceCommandOutput | UntagResourceCommandOutput | UpdateChannelCommandOutput | UpdateOriginEndpointCommandOutput;
export interface ClientDefaults extends Partial<__SmithyResolvedConfiguration<__HttpHandlerOptions>> {
    
    requestHandler?: __HttpHandler;
    
    sha256?: __HashConstructor;
    
    urlParser?: __UrlParser;
    
    bodyLengthChecker?: __BodyLengthCalculator;
    
    streamCollector?: __StreamCollector;
    
    base64Decoder?: __Decoder;
    
    base64Encoder?: __Encoder;
    
    utf8Decoder?: __Decoder;
    
    utf8Encoder?: __Encoder;
    
    runtime?: string;
    
    disableHostPrefix?: boolean;
    
    maxAttempts?: number | __Provider<number>;
    
    retryMode?: string | __Provider<string>;
    
    logger?: __Logger;
    
    useDualstackEndpoint?: boolean | __Provider<boolean>;
    
    useFipsEndpoint?: boolean | __Provider<boolean>;
    
    serviceId?: string;
    
    region?: string | __Provider<string>;
    
    credentialDefaultProvider?: (input: any) => __Provider<__Credentials>;
    
    regionInfoProvider?: RegionInfoProvider;
    
    defaultUserAgentProvider?: Provider<__UserAgent>;
    
    defaultsMode?: DefaultsMode | Provider<DefaultsMode>;
}
declare type MediaPackageClientConfigType = Partial<__SmithyConfiguration<__HttpHandlerOptions>> & ClientDefaults & RegionInputConfig & EndpointsInputConfig & RetryInputConfig & HostHeaderInputConfig & AwsAuthInputConfig & UserAgentInputConfig;

export interface MediaPackageClientConfig extends MediaPackageClientConfigType {
}
declare type MediaPackageClientResolvedConfigType = __SmithyResolvedConfiguration<__HttpHandlerOptions> & Required<ClientDefaults> & RegionResolvedConfig & EndpointsResolvedConfig & RetryResolvedConfig & HostHeaderResolvedConfig & AwsAuthResolvedConfig & UserAgentResolvedConfig;

export interface MediaPackageClientResolvedConfig extends MediaPackageClientResolvedConfigType {
}

export declare class MediaPackageClient extends __Client<__HttpHandlerOptions, ServiceInputTypes, ServiceOutputTypes, MediaPackageClientResolvedConfig> {
    
    readonly config: MediaPackageClientResolvedConfig;
    constructor(configuration: MediaPackageClientConfig);
    
    destroy(): void;
}
export {};
